--[[
    Baldrick_Classic_Alliance by LordFarlander
    Version 1.5.4    
    $Revision: 3 $
]]--

--[[
Copyright (c) 2008, LordFarlander
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
]]--

local Baldrick = _G["Baldrick"];

if( not Baldrick ) then
    error( L["%s requires %s"]:format( "Baldrick_Classic_Alliance", "Baldrick" ) );
    return;
end--if

local L = LibStub( "AceLocale-3.0" ):GetLocale( "Baldrick_Classic" );
local LBZ = LibStub( "LibBabble-Zone-3.0" );

if( LBZ ) then
    LBZ = LBZ:GetUnstrictLookupTable();
end--if

local ZONES = {};
setmetatable( ZONES, {
    __index = function( self, key )
            local returnVal = LBZ and LBZ[key];

            if( not returnVal ) then
                returnVal = L[key];
            end--if
            return returnVal;
        end } );

local NPCS = L;
local QuestObjectiveComplete = Baldrick.QuestObjectiveComplete;

local function IsTargetAliveAndNotTapped()
    return ( not UnitIsDead( "playertarget" ) ) and
       ( UnitIsTappedByPlayer( "playertarget" ) or ( not UnitIsTapped( "playertarget" ) ) );
end--IsTargetAliveAndNotTapped()

local function IsTargetDead()
    return UnitIsDead( "playertarget" );
end--IsTargetDead()

local quests = {
    --Eastern Kingdoms
    --Blackrock Mountain
    {
        --Bodley's Unfortunate Fate
        questIDs = 8960,
        --Extra-Dimensional Ghost Revealer
        questItems = { default = { questItem = 22115, questItemCount = 1, }, },
        subZones = ZONES["Blackrock Mountain"],
    },
    --Burning Steppes
    {
        --Ogre Head On A Stick = Party
        questIDs = 3825,
        --Gor'tesh's Lopped Off Head
        questItems = { default = { questItem = 11079, questItemCount = 1, }, },
        subZones = ZONES["Dreadmaul Rock"],
    },
    --Deeprun Tram
    {
        --Deeprun Rat Roundup
        questIDs = 6661,
        --Rat Catcher's Flute
        questItems = { default = { questItem = 17117, questItemCount = 1, }, },
        target = NPCS["Deeprun Rat"],
        func = IsTargetAliveAndNotTapped;
    },
    --Dun Moroh
    --Gnomeregan
    {
        --Gnogaine
        questIDs = 2926,
        --Empty Leaden Collection Phial
        questItems = { default = { questItem = 9283, questItemCount = 1, }, },
        subZones = ZONES["Gnomeregan"],
    },
    --Darkshire
    {
        --Morbent Fel
        questIDs = 55,
        --Morbent's Bane
        questItems = { default = { questItem = 7297, questItemCount = 1, }, },
        target = NPCS["Morbent Fel"],
        func = IsTargetAliveAndNotTapped;
    },
    --Eastern Plaguelands
    {
        --In Search of Anthion
        questIDs = 8929,
        --Extra-Dimensional Ghost Revealer
        questItems = { default = { questItem = 22115, questItemCount = 1, }, },
        subZones = ZONES["Stratholme"],
    },
    --Ironforge
    {
        --A Little Slime Goes a Long Way
        questIDs = 4512,
        --Empty Cursed Ooze Jar
        questItems = { default = { questItem = 11914, questItemCount = 1, }, },
        target = NPCS["Cursed Ooze"],
        func = function( _, questID )
                return IsTargetDead() and ( not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 11947 ) ) ) );
            end,
    },
    {
        --A Little Slime Goes a Long Way
        questIDs = 4512,
        --Empty Tainted Ooze Jar
        questItems = { default = { questItem = 11948, questItemCount = 1, }, },
        target = NPCS["Tainted Ooze"],
        func = function( _, questID )
                return IsTargetDead() and ( not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 11949 ) ) ) );
            end,
    },
    {
        --A Little Slime Goes a Long Way
        questIDs = 4513,
        --Empty Pure Sample Jar
        questItems = { default = { questItem = 11953, questItemCount = 1, }, },
        target = NPCS["Gargantuan Ooze"] .. "|" .. NPCS["Glutinous Ooze"] .. "|" .. NPCS["Muculent Ooze"] .. "|" .. NPCS["Primal Ooze"],
        func = IsTargetDead;
    },
    {
        --Arcane Runes
        questIDs = 3449,
        --Drawing Kit
        questItems = { default = { questItem = 10445, questItemCount = 1, }, },
        subZones = ZONES["Ruins of Eldarath"],
    },
    --Loch Modan
    {
        --Badlands Reagent Run II
        questIDs = 2501,
        --Empty Thaumaturgy Vessel
        questItems = { default = { questItem = 7866, questItemCount = 1, }, },
        target = NPCS["Scorched Guardian"],
    },
    --Stranglethorn Vale
    {
        --The Curse of the Tides
        questIDs = 611,
        --Catelyn's Blade
        questItems = { default = { questItem = 4027, questItemCount = 1, }, },
        subZones = ZONES["Stranglethorn Vale"],
        func = IsSwimming,
    },
    --Western Plaguelands
    {
        --A Plague Upon Thee
        questIDs = 5903,
        --Empty Termite Jar
        questItems = { default = { questItem = 15042, questItemCount = 1, }, },
        subZones = ZONES["Plaguewood"],
    },
    {
        --All Along the Watchtowers
        questIDs = 5097,
        --Beacon Torch
        questItems = { default = { questItem = 12815, questItemCount = 1, }, },
        subZones = ZONES["Andorhal"],
    },

    --Kalimdor
    --Ashenvale
    {
        --Raene's Cleansing
        questIDs = 1030,
        --Dartol's Rod of Transformation
        questItems = { default = { questItem = 5462, questItemCount = 1, } },
        additionalEvents = { "LibSpecialEvents-Aura-4.0:PlayerBuffGained", "LibSpecialEvents-Aura-4.0:PlayerBuffLost" },
        func =
            function()
                return not LibStub( "LibSpecialEvents-Aura-4.0" ):UnitHasBuff( "player", select( 1, GetSpellInfo( 6405 ) ) );
            end,
    },
    {
        --Raene's Cleansing
        questIDs = 1045,
        --Dartol's Rod of Transformation
        questItems = { default = { questItem = 5462, questItemCount = 1, } },
        additionalEvents = { "LibSpecialEvents-Aura-4.0:PlayerBuffGained", "LibSpecialEvents-Aura-4.0:PlayerBuffLost" },
        func =
            function()
                return not LibStub( "LibSpecialEvents-Aura-4.0" ):UnitHasBuff( "player", select( 1, GetSpellInfo( 6405 ) ) );
            end,
    },
    {
        --Elemental Bracers
        questIDs = 1016,
        --Divining Scroll, Intact Elemental Bracer
        questItems = { default = { questItem = 5456, questItemCount = 1, }, { questItem = 12220, questItemCount = 5, }, },
    },
    --Darkshore
    {
        --As Water Cascades
        questIDs = 4812,
        --Empty Water Tube
        questItems = { default = { questItem = 14338, questItemCount = 1, }, },
        subZones = ZONES["Auberdine"],
    },
    {
        --The Blackwood Corrupted
        questIDs = 4763,
        --Empty Cleansing Bowl
        questItems = { default = { questItem = 12346, questItemCount = 1, }, },
        subZones = ZONES["Auberdine"],
    },
    {
        --The Cliffspring River
        questIDs = 4762,
        --Empty Sampling Tube
        questItems = { default = { questItem = 12350, questItemCount = 1, }, },
        subZones = ZONES["Cliffspring River"],
    },
    {
        --The Blackwood Corrupted
        questIDs = 4763,
        --Filled Cleansing Bowl, Blackwood Fruit Sample, Blackwood Nut Sample, Blackwood Grain Sample
        questItems = { default = { questItem = 12347, questItemCount = 1, }, { questItem = 12341, questItemCount = 1, }, { questItem = 12343, questItemCount = 1, }, { questItem = 12342, questItemCount = 1, }, },
        subZones = ZONES["Darkshore"],
    },
    {
        --Plagued Lands
        questIDs = 2118,
        --Tharnariun's Hope
        questItems = { default = { questItem = 7586, questItemCount = 1, }, },
        target = NPCS["Rabid Thistle Bear"],
        func = IsTargetAliveAndNotTapped,
    },
    --Darnassus
    {
        --Morrowgrain Research
        questIDs = 3785,
        --Evergreen Pouch, Un'Goro Soil, Packet of Tharlendris Seeds
        questItems = { default = { questItem = 11020, questItemCount = 1, }, { questItem = 11018, questItemCount = 2, }, { questItem = 11022, questItemCount = 1, }, },
    },
    --Dustwallow Marsh
    {
        --Nat's Bargain
        questIDs = 11209,
        --Pagle's Fish Paste, Extra Strength
        questItems = { default = { questItem = 33166, questItemCount = 1, }, },
        subZones = ZONES["Dustwallow Marsh"],
        func = IsSwimming,
    },
    {
        --Recover the Cargo!
        questIDs = 11140,
        --Salvage Kit
        questItems = { default = { questItem = 33044, questItemCount = 1, }, },
        subZones = ZONES["Dustwallow Marsh"],
        func = IsSwimming,
    },
    {
        --Raze Direhorn Post!
        questIDs = 11150,
        --Tabetha's Torch
        questItems = { default = { questItem = 33072, questItemCount = 1, }, },
        subZones = ZONES["Direhorn Post"],
    },
    {
        --Unleash the Raptors
        questIDs = 11147,
        --Raptor Bait
        questItems = { default = { questItem = 33070, questItemCount = 1, }, },
        subZones = ZONES["Blackhoof Village"],
    },
    {
        --Raptor Captor
        questIDs = 11146,
        --Sturdy Rope
        questItems = { default = { questItem = 33069, questItemCount = 1, }, },
        target = NPCS["Bloodfen Raptor"] .. "|" .. NPCS["Bloodfen Screecher"],
        func = IsTargetAliveAndNotTapped,
    },
    --Felwood
    {
        --Felbound Ancients
        questIDs = 4441,
        --Eridan's Vial
        questItems = { default = { questItem = 11682, questItemCount = 1, }, },
        subZones = ZONES["Temple of the Moon"],
    },
    --Silithus
    {
        --Field Duty
        questIDs = 8507,
        --Unsigned Field Duty Papers
        questItems = { default = { questItem = 21143, questItemCount = 1, }, },
    },
    --Tanaris
    {
        --Fire Plume Forged
        questIDs = 5801,
        --Skeleton Key Mold, Thorium Bar
        questItems = { default = { questItem = 14644, questItemCount = 1, }, { questItem = 12359, questItemCount = 2, }, },
        subZones = ZONES["Fire Plume Ridge"],
    },
    --Teldrassil
    {
        --Crown of the Earth
        questIDs = 921,
        --Crystal Phial
        questItems = { default = { questItem = 5185, questItemCount = 1, }, },
        subZones = ZONES["Shadowglen"],
    },
    {
        --Crown of the Earth
        questIDs = 929,
        --Jade Phial
        questItems = { default = { questItem = 5619, questItemCount = 1, }, },
        subZones = ZONES["Starbreeze Village"],
    },
    {
        --Crown of the Earth
        questIDs = 933,
        --Tourmaline Phial
        questItems = { default = { questItem = 5621, questItemCount = 1, }, },
        subZones = ZONES["Teldrassil"],
    },
    {
        --Crown of the Earth
        questIDs = 7383,
        --Amethyst Phial
        questItems = { default = { questItem = 18152, questItemCount = 1, }, },
        subZones = ZONES["Oracle Glade"],
    },
    --Winterfall
    {
        --Troubled Spirits of Kel'Theril
        questIDs = 5245,
        --Jaron's Pick
        questItems = { default = { questItem = 12891, questItemCount = 1, }, },
        subZones = ZONES["Lake Kel'Theril"],
    },
};

Baldrick:RegisterQuestModule( L["Classic Alliance Quests"], quests, function() return UnitFactionGroup( "player" ) == "Alliance" end );
